@@ -1,9 +1,13 @@
+try:
+    import json
+except ImportError:
+    from django.utils import simplejson as json  # Python 2.5
 import logging
 
 from django import forms
 from django.db import models
 from django.core.serializers.json import DjangoJSONEncoder
-from django.utils import simplejson as json
+
 
 class JSONFormField(forms.fields.CharField):
     def clean(self, value, *args, **kwargs):
@@ -48,7 +52,7 @@ class JSONField(models.TextField):
             assert value is None
             return {}
 
-    def get_db_prep_value(self, value):
+    def get_prep_value(self, value):
         """Convert our JSON object to a string before we save"""
         return self._flatten_value(value)
 
@@ -82,4 +86,4 @@ try:
 
     add_introspection_rules(rules=[JSONField_introspection_rule], patterns=["^feincms\.contrib\.fields"])
 except ImportError:
-    pass
\ No newline at end of file
+    pass
